@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2011   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2012   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -39,18 +39,27 @@ public class RunExecute : EventExecute
 	//changes a bit on runSimple and runInterval
 	//explained at each of the updateTimeProgressBar() 
 	protected enum runPhases {
-		PRE_RUNNING, PLATFORM_INI, RUNNING, PLATFORM_END
+		PRE_RUNNING, PLATFORM_INI_YES_TIME, PLATFORM_INI_NO_TIME, RUNNING, PLATFORM_END
 	}
 	protected runPhases runPhase;
 		
+	protected bool checkDoubleContact;
+	protected int checkDoubleContactTime;
+	protected Constants.DoubleContact checkDoubleContactMode;
+	
+	protected bool speedStartArrival;	
 	
 	public RunExecute() {
 	}
 
 	//run execution
 	public RunExecute(int personID, int sessionID, string type, double distance,   
-			Chronopic cp, Gtk.TextView event_execute_textview_message, Gtk.Window app, int pDN, bool metersSecondsPreferred, bool volumeOn,
-			double progressbarLimit, ExecutingGraphData egd 
+			Chronopic cp, Gtk.Label event_execute_label_message, Gtk.Window app, 
+			int pDN, bool metersSecondsPreferred, bool volumeOn,
+			double progressbarLimit, ExecutingGraphData egd,
+			bool checkDoubleContact, int checkDoubleContactTime, 
+			Constants.DoubleContact checkDoubleContactMode,
+			bool speedStartArrival
 			)
 	{
 		this.personID = personID;
@@ -59,7 +68,7 @@ public class RunExecute : EventExecute
 		this.distance = distance;
 		
 		this.cp = cp;
-		this.event_execute_textview_message = event_execute_textview_message;
+		this.event_execute_label_message = event_execute_label_message;
 		this.app = app;
 
 		this.pDN = pDN;
@@ -67,6 +76,10 @@ public class RunExecute : EventExecute
 		this.volumeOn = volumeOn;
 		this.progressbarLimit = progressbarLimit;
 		this.egd = egd;
+		this.checkDoubleContact = checkDoubleContact;
+		this.checkDoubleContactTime = checkDoubleContactTime;
+		this.checkDoubleContactMode = checkDoubleContactMode;
+		this.speedStartArrival = speedStartArrival;	
 		
 		fakeButtonUpdateGraph = new Gtk.Button();
 		fakeButtonEventEnded = new Gtk.Button();
@@ -120,7 +133,7 @@ Log.WriteLine("MANAGE(b)!!!!");
 
 			loggedState = States.ON;
 			startIn = true;
-			runPhase = runPhases.PLATFORM_INI;
+			runPhase = runPhases.PLATFORM_INI_NO_TIME;
 		} else if (platformState==Chronopic.Plataforma.OFF) {
 			feedbackMessage = Catalog.GetString("You are OUT, RUN when prepared!");
 			needShowFeedbackMessage = true; 
@@ -174,8 +187,13 @@ Log.WriteLine("MANAGE(3)!!!!");
 	protected override void waitEvent ()
 	{
 		double timestamp = 0;
+		double timestampFirstContact = 0; //used when runPhase == runPhases.PLATFORM_INI_YES_TIME;
+
+		double timestampDCFlightTimes = -1; //sum of the flight times that happen in small time
+		double timestampDCContactTimes = -1;//sum of the contact times that happen in small time
+		double timestampDCn = 0; //number of flight times
+
 		bool success = false;
-		
 		bool ok;
 
 		do {
@@ -186,12 +204,17 @@ Log.WriteLine("MANAGE(3)!!!!");
 			
 			//if (ok) {
 			if (ok && !cancel) {
+//Log.WriteLine("timestamp:" + timestamp);
 				if (platformState == Chronopic.Plataforma.ON && loggedState == States.OFF) {
 					//has arrived
 					loggedState = States.ON;
 					
 					if(runPhase == runPhases.PRE_RUNNING) {
-						runPhase = runPhases.PLATFORM_INI;
+						if(speedStartArrival) {
+							runPhase = runPhases.PLATFORM_INI_YES_TIME;
+							initializeTimer(); //timerCount = 0
+						} else
+							runPhase = runPhases.PLATFORM_INI_NO_TIME;
 						
 						updateProgressBar = new UpdateProgressBar (
 								true, //isEvent
@@ -206,44 +229,98 @@ Log.WriteLine("MANAGE(3)!!!!");
 						
 						if(simulated)
 							timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
-						
-						time = timestamp / 1000.0;
-						write();
 
-						success = true;
+						//prevent double contact stuff
+						if(checkDoubleContact) {
+							if(timestamp <= checkDoubleContactTime) {
+								/*
+								   when checking double contact
+								   first time that timestamp < checkDoubleContactTime
+								   and we arrived (it's a flight time)
+								   record this time as timestampDCFlightTimes
+								 */
+								timestampDCn ++;
+								timestampDCFlightTimes += timestamp;
+							}
+							else {
+								if(timestampDCn > 0) {
+									if(checkDoubleContactMode == 
+											Constants.DoubleContact.FIRST) {
+										/* user want first flight time,
+										   then add all DC times*/
+										timestamp += timestampDCFlightTimes + 
+											timestampDCContactTimes;
+									}
+									else if(checkDoubleContactMode == 
+											Constants.DoubleContact.LAST) {
+										//user want last flight time, take that
+										timestamp = timestamp;
+									}
+									else {	/* do the avg of all flights and contacts
+										   then add to last timestamp */
+										timestamp += 
+											(timestampDCFlightTimes + 
+											 timestampDCContactTimes) 
+											/ timestampDCn;
+									}
+								}
+								success = true;
+							}
+						}
 						
-						updateProgressBar = new UpdateProgressBar (
-								true, //isEvent
-								true, //percentageMode
-								//percentageToPass
-								3
-								);  
-						needUpdateEventProgressBar = true;
-						
-						runPhase = runPhases.PLATFORM_END;
+						if(! checkDoubleContact)
+							success = true;
+
+						if(success) {
+							//add the first contact time if PLATFORM_INI_YES_TIME
+							if(timestampFirstContact > 0)
+								timestamp += timestampFirstContact;
+
+							time = timestamp / 1000.0;
+							write();
+
+							//success = true;
+
+							updateProgressBar = new UpdateProgressBar (
+									true, //isEvent
+									true, //percentageMode
+									//percentageToPass
+									3
+									);  
+							needUpdateEventProgressBar = true;
+
+							runPhase = runPhases.PLATFORM_END;
+						}
 					}
 				}
 				else if (platformState == Chronopic.Plataforma.OFF && loggedState == States.ON) {
 					//it's out, was inside (= has abandoned platform)
 					//don't record time
 						
-					initializeTimer();
-						
-					//update event progressbar
-					updateProgressBar = new UpdateProgressBar (
-							true, //isEvent
-							true, //percentageMode
-							2 //normal run, phase 2/3
-							);  
-					needUpdateEventProgressBar = true;
-					
-					feedbackMessage = "";
-					needShowFeedbackMessage = true; 
-					
 					//change the automata state
 					loggedState = States.OFF;
-						
-					runPhase = runPhases.RUNNING;
+
+					if(checkDoubleContact && timestampDCn > 0)
+						timestampDCContactTimes += timestamp;
+					else {
+						if(runPhase == runPhases.PLATFORM_INI_YES_TIME)
+							timestampFirstContact = timestamp;
+						else if(runPhase == runPhases.PLATFORM_INI_NO_TIME)
+							initializeTimer(); //timerCount = 0
+
+						//update event progressbar
+						updateProgressBar = new UpdateProgressBar (
+								true, //isEvent
+								true, //percentageMode
+								2 //normal run, phase 2/3
+								);  
+						needUpdateEventProgressBar = true;
+
+						feedbackMessage = "";
+						needShowFeedbackMessage = true; 
+
+						runPhase = runPhases.RUNNING;
+					}
 				}
 			}
 		} while ( ! success && ! cancel );
@@ -261,15 +338,20 @@ Log.WriteLine("MANAGE(3)!!!!");
 	}
 	
 	protected override void updateTimeProgressBar() {
-		/* 4 situations:
-		 *   1- if we start out and have not arrived to platform, it should be a pulse with no time value on label
-			case runPhases.PRE_RUNNING:
-		 *   2-  if we are on the platform, it should be a pulse with no time value on label
-			case runPhases.PLATFORM_INI:
-		 *   3- if we leave the platform, it should be a pulse with timerCount on label
-			case runPhases.RUNNING:
-		 *   4- if we arrive (finish), it should be a pulse with chronopic time on label
-			case runPhases.PLATFORM_END:
+		/* 5 situations:
+		 *   1- if we start out and have not arrived to platform, it should be a pulse with no time value on label:
+		 *		case runPhases.PRE_RUNNING
+		 *   2-  if we are on the platform, it should be a pulse
+		 *   		a) if speedStartArrival (time starts at arriving at platform) 
+		 *   		then time starts and have to be time value on label:
+		 *			case runPhases.PLATFORM_INI_YES_TIME
+		 *   		b) if ! speedStartArrival (time starts at leaving platform)
+		 *   		then time starts and do not have to be time value on label:
+		 *			case runPhases.PLATFORM_INI_NO_TIME
+		 *   3- if we leave the platform, it should be a pulse with timerCount on label:
+		 *		case runPhases.RUNNING
+		 *   4- if we arrive (finish), it should be a pulse with chronopic time on label:
+		 *		case runPhases.PLATFORM_END
 		 */
 		
 		double myTimeValue = 0;
@@ -277,9 +359,12 @@ Log.WriteLine("MANAGE(3)!!!!");
 			case runPhases.PRE_RUNNING:
 				myTimeValue = -1; //don't show nothing on label_timer 
 				break;
-			case runPhases.PLATFORM_INI:
+			case runPhases.PLATFORM_INI_NO_TIME:
 				myTimeValue = -1;
 				break;
+			case runPhases.PLATFORM_INI_YES_TIME:
+				myTimeValue = timerCount; //show time from the timerCount
+				break;
 			case runPhases.RUNNING:
 				myTimeValue = timerCount; //show time from the timerCount
 				break;
@@ -369,7 +454,10 @@ public class RunIntervalExecute : RunExecute
 
 
 	string distancesString; //if distances are variable (distanceInterval == -1), this is used
-	double distanceIntervalFixed; //if distanceInterval i -1, then Fixed is the corresponding base on distancesString
+	double distanceIntervalFixed; //if distanceInterval == -1, then Fixed is the corresponding base on distancesString
+	double lastTc;		//useful to know time on contact platform because intervalTimesString does not differentiate
+							
+	bool RSABellDone;
 
 	//private Chronopic cp;
 
@@ -378,9 +466,12 @@ public class RunIntervalExecute : RunExecute
 
 	//run execution
 	public RunIntervalExecute(int personID, int sessionID, string type, double distanceInterval, double limitAsDouble, bool tracksLimited,  
-			Chronopic cp, Gtk.TextView event_execute_textview_message, Gtk.Window app, int pDN, bool metersSecondsPreferred, 
+			Chronopic cp, Gtk.Label event_execute_label_message, Gtk.Window app, int pDN, bool metersSecondsPreferred, 
 			bool volumeOn, RepetitiveConditionsWindow repetitiveConditionsWin,
-			double progressbarLimit, ExecutingGraphData egd 
+			double progressbarLimit, ExecutingGraphData egd ,
+			bool checkDoubleContact, int checkDoubleContactTime, 
+			Constants.DoubleContact checkDoubleContactMode,
+			bool speedStartArrival
 			)
 	{
 		this.personID = personID;
@@ -397,6 +488,7 @@ public class RunIntervalExecute : RunExecute
 			distancesString = runType.DistancesString;
 		}
 
+
 		if(tracksLimited) {
 			this.limited = limitAsDouble.ToString() + "R"; //'R'uns (don't put 'T'racks for not confusing with 'T'ime)
 		} else {
@@ -406,7 +498,7 @@ public class RunIntervalExecute : RunExecute
 		
 		
 		this.cp = cp;
-		this.event_execute_textview_message = event_execute_textview_message;
+		this.event_execute_label_message = event_execute_label_message;
 		this.app = app;
 
 		this.metersSecondsPreferred = metersSecondsPreferred;
@@ -415,6 +507,10 @@ public class RunIntervalExecute : RunExecute
 		this.repetitiveConditionsWin = repetitiveConditionsWin;
 		this.progressbarLimit = progressbarLimit;
 		this.egd = egd;
+		this.checkDoubleContact = checkDoubleContact;
+		this.checkDoubleContactTime = checkDoubleContactTime;
+		this.checkDoubleContactMode = checkDoubleContactMode;
+		this.speedStartArrival = speedStartArrival;	
 	
 		fakeButtonUpdateGraph = new Gtk.Button();
 		fakeButtonEventEnded = new Gtk.Button();
@@ -431,31 +527,28 @@ public class RunIntervalExecute : RunExecute
 		eventDone = new RunInterval();
 	}
 
-	
+
 	protected override void waitEvent ()
 	{
 		double timestamp = 0;
 		bool success = false;
 		string equal = "";
 		
-		
 		//initialize variables
 		intervalTimesString = "";
 		tracks = 0;
-		
 		bool ok;
-
 		timerCount = 0;
 		//bool initialized = false;
-		
 		int countForSavingTempTable = 0;
-	
-		double lastTc = 0;
-					
+		lastTc = 0;
 		distanceIntervalFixed = distanceInterval;
+
+		double timestampDCFlightTimes = -1; //sum of the flight times that happen in small time
+		double timestampDCContactTimes = -1;//sum of the contact times that happen in small time
+		double timestampDCn = 0; //number of flight times
 		
 		do {
-
 			if(simulated) 
 				ok = true;
 			else 
@@ -470,12 +563,19 @@ public class RunIntervalExecute : RunExecute
 					//has arrived
 					loggedState = States.ON;
 					
-					//if we start out, and we arrive to the platform for the first time, don't record nothing
-					if(runPhase == runPhases.PRE_RUNNING) {
-						runPhase = runPhases.RUNNING;
-						//run starts
-						initializeTimer();
+					//show RSA count down only on air		
+					needShowCountDown = false;
 					
+					//if we start out, and we arrive to the platform for the first time,
+					//don't record nothing
+					if(runPhase == runPhases.PRE_RUNNING) {
+						if(speedStartArrival) {
+							runPhase = runPhases.PLATFORM_INI_YES_TIME;
+							//run starts
+							initializeTimer(); //timerCount = 0
+						} else
+							runPhase = runPhases.PLATFORM_INI_NO_TIME;
+
 						feedbackMessage = "";
 						needShowFeedbackMessage = true; 
 					}
@@ -485,62 +585,74 @@ public class RunIntervalExecute : RunExecute
 						
 						//if interval run is "unlimited" not limited by tracks, nor time, 
 						//then play with the progress bar until finish button is pressed
+						
+						if(simulated)
+							timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
+
+						if(checkDoubleContact) {
+							if(timestamp <= checkDoubleContactTime) {
+								/*
+								   when checking double contact
+								   first time that timestamp < checkDoubleContactTime
+								   and we arrived (it's a flight time)
+								   record this time as timestampDCFlightTimes
+								 */
+								timestampDCn ++;
+								timestampDCFlightTimes += timestamp;
+								continue;
+							}
+							else {
+								if(timestampDCn > 0) {
+									if(checkDoubleContactMode == 
+											Constants.DoubleContact.FIRST) {
+										/* user want first flight time,
+										   then add all DC times*/
+										timestamp += timestampDCFlightTimes + 
+											timestampDCContactTimes;
+									}
+									else if(checkDoubleContactMode == 
+											Constants.DoubleContact.LAST) {
+										//user want last flight time, take that
+										timestamp = timestamp;
+									}
+									else {	/* do the avg of all flights and contacts
+										   then add to last timestamp */
+										timestamp += 
+											(timestampDCFlightTimes + 
+											 timestampDCContactTimes) 
+											/ timestampDCn;
+									}
+								}
+							}
+						}
+
+						double myRaceTime = lastTc + timestamp/1000.0;
+
+						if(intervalTimesString.Length > 0) { equal = "="; }
+						intervalTimesString = intervalTimesString + equal + myRaceTime.ToString();
+						updateTimerCountWithChronopicData(intervalTimesString);
+						tracks ++;	
+
+						//save temp table if needed
+						countForSavingTempTable ++;
+						if(countForSavingTempTable == timesForSavingRepetitive) {
+								writeRunInterval(true); //tempTable
+								countForSavingTempTable = 0;
+						}
+					
 						if(limitAsDouble == -1) {
-							
-							if(simulated)
-								timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
-							
-							double myRaceTime = lastTc + timestamp/1000.0;
-							
-							if(intervalTimesString.Length > 0) { equal = "="; }
-							intervalTimesString = intervalTimesString + equal + myRaceTime.ToString();
-							updateTimerCountWithChronopicData(intervalTimesString);
-							tracks ++;	
-								
+							//has arrived, unlimited
 							updateProgressBar= new UpdateProgressBar (
 									true, //isEvent
 									true, //unlimited: activity mode
 									tracks
 									);  
 							needUpdateEventProgressBar = true;
-							
-							distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracks);
-
-							//update graph
-							PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
-									distanceIntervalFixed, myRaceTime, intervalTimesString, distanceTotal, distancesString);
-
-							needUpdateGraphType = eventType.RUNINTERVAL;
-							needUpdateGraph = true;
-							
-							
-							//put button_finish as sensitive when first jump is done (there's something recordable)
-							if(tracks == 1)
-								needSensitiveButtonFinish = true;
 						}
 						else {
 							//has arrived, limited
 							if (tracksLimited) {
 								//has arrived, limited by tracks
-								tracks ++;	
-
-								if(simulated)
-									timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
-
-								double myRaceTime = lastTc + timestamp/1000.0;
-								if(intervalTimesString.Length > 0) { equal = "="; }
-								intervalTimesString = intervalTimesString + equal + myRaceTime.ToString();
-								updateTimerCountWithChronopicData(intervalTimesString);
-
-
-								//save temp table if needed
-								countForSavingTempTable ++;
-								if(countForSavingTempTable == timesForSavingRepetitive) {
-									writeRunInterval(true); //tempTable
-									countForSavingTempTable = 0;
-								}
-
-	
 								if(tracks >= limitAsDouble) 
 								{
 									//finished
@@ -548,7 +660,6 @@ public class RunIntervalExecute : RunExecute
 									success = true;
 									runPhase = runPhases.PLATFORM_END;
 								}
-								
 								//progressBarEventOrTimePreExecution(
 								updateProgressBar= new UpdateProgressBar (
 										true, //isEvent
@@ -556,95 +667,72 @@ public class RunIntervalExecute : RunExecute
 										tracks
 										);  
 								needUpdateEventProgressBar = true;
-							
-								distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracks);
-							
-								//update graph
-								PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
-										distanceIntervalFixed, myRaceTime, intervalTimesString, distanceTotal, distancesString);
-
-								needUpdateGraphType = eventType.RUNINTERVAL;
-								needUpdateGraph = true;
-
-								//put button_finish as sensitive when first jump is done (there's something recordable)
-								if(tracks == 1)
-									needSensitiveButtonFinish = true;
 							} else {
 								//has arrived, limited by time
-								runPhase = runPhases.RUNNING;
-								
-								if(simulated)
-									timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
-								
-								double myRaceTime = lastTc + timestamp/1000.0;
-								if(success) {
-									//write();
-									//write only if there's a run at minimum
-									if(Util.GetNumberOfJumps(intervalTimesString, false) >= 1) {
-										writeRunInterval(false); //tempTable = false
-									} else {
-										//cancel a run if clicked finish before any events done, or ended by time without events
-										cancel = true;
-									}
-
-									runPhase = runPhases.PLATFORM_END;
-								}
-								else {
-									if(intervalTimesString.Length > 0) { equal = "="; }
-									intervalTimesString = intervalTimesString + equal + myRaceTime.ToString();
-									updateTimerCountWithChronopicData(intervalTimesString);
-									tracks ++;	
-								
-									//save temp table if needed
-									countForSavingTempTable ++;
-									if(countForSavingTempTable == timesForSavingRepetitive) {
-										writeRunInterval(true); //tempTable
-										countForSavingTempTable = 0;
-									}
-
-								}
-								
 								updateProgressBar= new UpdateProgressBar (
 										true, //isEvent
 										false, //timeLimited: activity mode
 										tracks
 										);  
 								needUpdateEventProgressBar = true;
-								
-								distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracks);
-							
-								//update graph
-								PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
-										distanceIntervalFixed, myRaceTime, intervalTimesString, distanceTotal, distancesString);
-
-								needUpdateGraphType = eventType.RUNINTERVAL;
-								needUpdateGraph = true;
-
-								//put button_finish as sensitive when first jump is done (there's something recordable)
-								if(tracks == 1)
-									needSensitiveButtonFinish = true;
 							}
 						}
+
+						distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracks);
+
+						//update graph
+						PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
+								distanceIntervalFixed, myRaceTime, intervalTimesString, 
+								distanceTotal, distancesString);
+
+						needUpdateGraphType = eventType.RUNINTERVAL;
+						needUpdateGraph = true;
+
+						//put button_finish as sensitive when first jump is done (there's something recordable)
+						if(tracks == 1)
+							needSensitiveButtonFinish = true;
 					}
 				}
 				else if (platformState == Chronopic.Plataforma.OFF && loggedState == States.ON) {
 					//it's out, was inside (= has abandoned platform)
-		
-					if(runPhase == runPhases.PLATFORM_INI) {
+							
+					if(runPhase == runPhases.PLATFORM_INI_NO_TIME) {
 						//run starts
 						initializeTimer();
 						lastTc = 0;
 
 						feedbackMessage = "";
 						needShowFeedbackMessage = true; 
-					} else
+					} else if(runPhase == runPhases.PLATFORM_INI_YES_TIME) {
 						lastTc = timestamp/1000.0;
+					
+						feedbackMessage = "";
+						needShowFeedbackMessage = true; 
+					} else {
+						if(checkDoubleContact && timestampDCn > 0)
+							timestampDCContactTimes += timestamp;
+						else {
+							  lastTc = timestamp/1000.0;
+
+							  //RSA
+							  double RSAseconds = Util.GetRunIVariableDistancesThisRowIsRSA(
+										distancesString, Convert.ToInt32(tracks));
+							  if(RSAseconds > 0) {
+								    RSABellDone = false;
+								    needShowCountDown = true;
+							  } else {
+								    needShowCountDown = false;
+								    feedbackMessage = "";
+								    needShowFeedbackMessage = true;
+							  }
+						}
+					}
+
 						
 					runPhase = runPhases.RUNNING;
 
 					//change the automata state
 					loggedState = States.OFF;
-
 				}
 			}
 		} while ( ! success && ! cancel && ! finish );
@@ -670,36 +758,56 @@ public class RunIntervalExecute : RunExecute
 			totallyCancelled = true;
 		}
 	}
-	
+
+	protected override string countDownMessage() {
+		double waitSeconds = Util.GetRunIVariableDistancesThisRowIsRSA(distancesString, Convert.ToInt32(tracks))
+			 - (timerCount - Util.GetTotalTime(intervalTimesString) - lastTc);
+
+		if (waitSeconds < 0) {
+		       	if(! RSABellDone) {
+				Util.PlaySound(Constants.SoundTypes.GOOD, volumeOn);
+				RSABellDone = true;
+			}
+			return Catalog.GetString("Go!");
+		} else {
+			return string.Format(Catalog.GetPluralString(
+						"Wait 1 second.",
+						"Wait {0} seconds.",
+						Convert.ToInt32(Math.Ceiling(waitSeconds))),
+					Math.Ceiling(waitSeconds));
+		}
+
+	}
+
 	protected override bool shouldFinishByTime() {
 		//check if it should finish now (time limited, not unlimited and time exceeded)
 		//check that the run started
 		//if( ! tracksLimited && limitAsDouble != -1 && timerCount > limitAsDouble 
 		if( ! tracksLimited && limitAsDouble != -1 && Util.GetTotalTime(intervalTimesString) > limitAsDouble 
-				&& !(runPhase == runPhases.PRE_RUNNING) && !(runPhase == runPhases.PLATFORM_INI)) 
+				&& !(runPhase == runPhases.PRE_RUNNING) 
+				&& !(runPhase == runPhases.PLATFORM_INI_NO_TIME)
+				&& !(runPhase == runPhases.PLATFORM_INI_YES_TIME)
+				) 
 			return true;
 		else
 			return false;
 	}
 	
-	protected override void updateProgressBarForFinish() {
-		progressBarEventOrTimePreExecution(
-				false, //isEvent false: time
-				true, //percentageMode: it has finished, show bar at 100%
-				limitAsDouble
-				);  
-	}
-
 	protected override void updateTimeProgressBar() {
-		/* 4 situations:
-		 *   1- if we start out and have not arrived to platform, it should be a pulse with no time value on label 
-		 *   	case runPhases.PRE_RUNNING:
-		 *   2- we started in, and we haven't leaved the platform, a pulse but with no time value on label
-		 *   	case runPhases.PLATFORM_INI:
-		 *   3- we are in the platform or outside at any time except 1,2 and 4. timerCount have to be shown, and progress should be Fraction or Pulse depending on if ot's time limited or not
-		 *   	case runPhases.RUNNING:
-		 *  4.- we have arrived (or jump finished at any time)
-		 *   	case runPhases.PLATFORM_END:
+		/* 5 situations:
+		 *   1- if we start out and have not arrived to platform, it should be a pulse with no time value on label:
+		 *		case runPhases.PRE_RUNNING
+		 *   2-  if we are on the platform, it should be a pulse
+		 *   		a) if speedStartArrival (time starts at arriving at platform) 
+		 *   		then time starts and have to be time value on label:
+		 *			case runPhases.PLATFORM_INI_YES_TIME
+		 *   		b) if ! speedStartArrival (time starts at leaving platform)
+		 *   		then time starts and do not have to be time value on label:
+		 *			case runPhases.PLATFORM_INI_NO_TIME
+		 *   3- we are in the platform or outside at any time except 1,2 and 4. timerCount have to be shown, and progress should be Fraction or Pulse depending on if it's time limited or not:
+		 *		case runPhases.RUNNING
+		 *   4- if we arrive (finish), it should be a pulse with chronopic time on label:
+		 *		case runPhases.PLATFORM_END
 		 */
 		
 		double myTimeValue = 0;
@@ -709,10 +817,14 @@ public class RunIntervalExecute : RunExecute
 				percentageMode = false;
 				myTimeValue = -1; //don't show nothing on label_timer 
 				break;
-			case runPhases.PLATFORM_INI:
+			case runPhases.PLATFORM_INI_NO_TIME:
 				percentageMode = false;
 				myTimeValue = -1;
 				break;
+			case runPhases.PLATFORM_INI_YES_TIME:
+				percentageMode = !tracksLimited;
+				myTimeValue = timerCount; //show time from the timerCount
+				break;
 			case runPhases.RUNNING:
 				percentageMode = !tracksLimited;
 				myTimeValue = timerCount; //show time from the timerCount
@@ -723,13 +835,14 @@ public class RunIntervalExecute : RunExecute
 				//but chronojump.cs will update info soon with chronopic value
 				break;
 		}
-				
-		progressBarEventOrTimePreExecution(
-				false, //isEvent false: time
-				//!tracksLimited, //if tracksLimited: activity, if timeLimited: fraction
-				percentageMode,
-				myTimeValue
-				); 
+			
+		if(! finish) 
+			progressBarEventOrTimePreExecution(
+					false, //isEvent false: time
+					//!tracksLimited, //if tracksLimited: activity, if timeLimited: fraction
+					percentageMode,
+					myTimeValue
+					); 
 	}
 
 	private void updateTimerCountWithChronopicData(string timesString) {
@@ -739,14 +852,14 @@ public class RunIntervalExecute : RunExecute
 				
 	protected void writeRunInterval(bool tempTable)
 	{
-		int tracks = 0;
+		int tracksHere = 0; //different than globakl tracks variable
 		string limitString = "";
 
 		//if user clicked in finish earlier
 		if(finish) {
 			if(tracksLimited) {
-				tracks = Util.GetNumberOfJumps(intervalTimesString, false);
-				limitString = tracks.ToString() + "R";
+				tracksHere = Util.GetNumberOfJumps(intervalTimesString, false);
+				limitString = tracksHere.ToString() + "R";
 			} else {
 				//when we mark that run should finish by time, chronopic thread is probably capturing data
 				//check if it captured more than date limit, and if it has done, delete last(s) run(s)
@@ -773,22 +886,22 @@ public class RunIntervalExecute : RunExecute
 						}
 					}
 				}
-				//tracks are defined here (and not before) because can change on "while(eventPassed)" before
-				tracks = Util.GetNumberOfJumps(intervalTimesString, false);
+				//tracksHere are defined here (and not before) because can change on "while(eventPassed)" before
+				tracksHere = Util.GetNumberOfJumps(intervalTimesString, false);
 				limitString = Util.GetTotalTime(intervalTimesString) + "T";
 			}
 		} else {
 			if(tracksLimited) {
 				limitString = limitAsDouble.ToString() + "R";
-				tracks = (int) limitAsDouble;
+				tracksHere = (int) limitAsDouble;
 			} else {
 				limitString = limitAsDouble.ToString() + "T";
 				string [] myStringFull = intervalTimesString.Split(new char[] {'='});
-				tracks = myStringFull.Length;
+				tracksHere = myStringFull.Length;
 			}
 		}
 
-		distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracks);
+		distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracksHere);
 		timeTotal = Util.GetTotalTime(intervalTimesString); 
 		
 
@@ -800,7 +913,7 @@ public class RunIntervalExecute : RunExecute
 		if(tempTable)
 			SqliteRunInterval.Insert(false, Constants.TempRunIntervalTable, "NULL", personID, sessionID, type, 
 					distanceTotal, timeTotal,
-					distanceInterval, intervalTimesString, tracks, 
+					distanceInterval, intervalTimesString, tracksHere, 
 					description,
 					limitString,
 					Util.BoolToNegativeInt(simulated),
@@ -809,7 +922,7 @@ public class RunIntervalExecute : RunExecute
 		else {
 			uniqueID = SqliteRunInterval.Insert(false, Constants.RunIntervalTable, "NULL", personID, sessionID, type, 
 					distanceTotal, timeTotal,
-					distanceInterval, intervalTimesString, tracks, 
+					distanceInterval, intervalTimesString, tracksHere, 
 					description,
 					limitString,
 					Util.BoolToNegativeInt(simulated),
@@ -817,14 +930,14 @@ public class RunIntervalExecute : RunExecute
 					);
 
 			//define the created object
-			eventDone = new RunInterval(uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString, tracks, description, limitString, Util.BoolToNegativeInt(simulated), !startIn); 
+			eventDone = new RunInterval(uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString, tracksHere, description, limitString, Util.BoolToNegativeInt(simulated), !startIn); 
 
 
 			string tempValuesString = "";
 			if(tracksLimited) 
-				tempValuesString = " (" + distanceIntervalFixed + "x" + tracks + "R), " + Catalog.GetString("Time") + ": " + Util.TrimDecimals( timeTotal.ToString(), pDN);
+				tempValuesString = " (" + distanceIntervalFixed + "x" + tracksHere + "R), " + Catalog.GetString("Time") + ": " + Util.TrimDecimals( timeTotal.ToString(), pDN);
 			else
-				tempValuesString = " (" + distanceIntervalFixed + "x" + Util.TrimDecimals( timeTotal.ToString(), pDN) + "T), " + Catalog.GetString("Tracks") + ": " + tracks;
+				tempValuesString = " (" + distanceIntervalFixed + "x" + Util.TrimDecimals( timeTotal.ToString(), pDN) + "T), " + Catalog.GetString("Tracks") + ": " + tracksHere;
 
 			/*
 			string myStringPush =   Catalog.GetString("Last run") + ": " + RunnerName + ", " + 
@@ -898,11 +1011,10 @@ public class RunIntervalExecute : RunExecute
 	public override double Speed
 	{
 		get { 
-			//if(metersSecondsPreferred) {
+			//if(metersSecondsPreferred) 
 				return distanceTotal / timeTotal ; 
-			// else {
+			// else 
 			//	return (distanceTotal / timeTotal) * 3.6 ; 
-			//}
 		}
 	}
 */
